@@ -7,7 +7,7 @@ bd.shifts.optim <- function(x,sampling,grid,start,end,maxitk=5,yule=FALSE,ME=FAL
 	convfail<-vector()
 	if (length(miniall)==1){
 		miniall<-list()
-		est0<-bd.ME.optim(x,c(0),c(sampling[1]),yule,survival,groups=groups)
+		est0<-bd.ME.optim(x,c(0),c(sampling[1]),yule,survival=survival,posdiv=posdiv,groups=groups)
 		if (yule==FALSE){
 		if (est0[[1]]$convergence != 0){
 			print("convergence problem")
@@ -65,12 +65,10 @@ bd.shifts.optim <- function(x,sampling,grid,start,end,maxitk=5,yule=FALSE,ME=FAL
 			if (ME==FALSE){
 				temp<-bd.ME.optim(x,timetemp,sampling[1:length(timetemp)],yule,maxitk,init,posdiv,survival,groups=groups)}
 				#test<-partransformvector(c(init,timetemp[-1]))
-				#test2<-treemrca(x,test[3,],test[1,],test[2,],sampling[1:length(timetemp)])
 			else if ( all==TRUE){
 				temp<-bd.ME.optim.rho.all(x,timetemp,sampling[1],yule,maxitk,init,posdiv,survival)
 				print("higher taxa are ignored. groups = 0")
 				#test<-partransformvectorrho(c(init,timetemp[-1]),sampling[1])
-				#test2<-treemrca(x,test[4,],test[1,],test[2,],test[3,])
 			} else {
 				print(init)
 				temp<-bd.ME.optim.rho(x,timetemp,sampling[1],yule,maxitk,init,posdiv,survival)
